import { ɵɵdefineInjectable, Injectable, ɵɵinject, Component, Input, NgModule } from '@angular/core';
import { ReplaySubject, merge, timer } from 'rxjs';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { finalize, partition, switchMap, debounce, distinctUntilChanged, tap } from 'rxjs/operators';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';

class NgxHttpLoaderInterceptor {
    constructor() {
        this.reqStatus$ = new ReplaySubject(1);
        this.pendingReqCnt = 0;
        this.forceStop = false;
        this.filterUrls = [];
        this.filterUrlPatterns = [];
        this.filterMethods = [];
        this.filterHeaders = [];
    }
    get pendingRequestCnt() {
        return this.pendingRequestCnt;
    }
    get reqStatus() {
        return this.reqStatus$.asObservable();
    }
    set setFilterUrls(urls) {
        this.filterUrls = urls;
    }
    set setUrlPatterns(regx) {
        this.filterUrlPatterns = regx;
    }
    set setFilterMethods(methods) {
        this.filterMethods = methods;
    }
    set setFilterHeaders(headers) {
        this.filterHeaders = headers;
    }
    set setForceStopReq(bool) {
        this.forceStop = bool;
    }
    checkIsFilterUrl(url) {
        return this.filterUrls.some(x => x === url);
    }
    checkUrlPatterns(url) {
        return this.filterUrlPatterns.some(x => x.test(url));
    }
    checkHttpMethod(req) {
        return this.filterMethods.some(e => {
            return e.toLowerCase() === req.method.toLowerCase();
        });
    }
    checkReqHeader(req) {
        return this.filterHeaders.some(e => {
            return req.headers.has(e);
        });
    }
    isStopReq(r) {
        return this.forceStop
            || this.checkIsFilterUrl(r.urlWithParams)
            || this.checkUrlPatterns(r.urlWithParams)
            || this.checkHttpMethod(r)
            || this.checkReqHeader(r);
    }
    intercept(request, next) {
        const isNext = this.isStopReq(request);
        if (!isNext) {
            this.pendingReqCnt++;
            if (1 === this.pendingReqCnt) {
                this.reqStatus$.next(true);
            }
        }
        return next.handle(request).pipe(finalize(() => {
            if (!isNext) {
                this.pendingReqCnt--;
                if (0 === this.pendingReqCnt) {
                    this.reqStatus$.next(false);
                }
            }
        }));
    }
}
NgxHttpLoaderInterceptor.ɵprov = ɵɵdefineInjectable({ factory: function NgxHttpLoaderInterceptor_Factory() { return new NgxHttpLoaderInterceptor(); }, token: NgxHttpLoaderInterceptor, providedIn: "root" });
NgxHttpLoaderInterceptor.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
const RequestsInterceptorProvider = [{
        provide: HTTP_INTERCEPTORS,
        useExisting: NgxHttpLoaderInterceptor,
        multi: true
    }];

class NgxHttpLoaderService {
    constructor(reqService) {
        this.reqService = reqService;
        this.showLoader = new ReplaySubject(1);
    }
    get isShowLoader() {
        return this.showLoader.asObservable();
    }
    show() {
        this.reqService.setForceStopReq = true;
        this.showLoader.next(true);
    }
    hide() {
        this.showLoader.next(false);
        this.reqService.setForceStopReq = false;
    }
}
NgxHttpLoaderService.ɵprov = ɵɵdefineInjectable({ factory: function NgxHttpLoaderService_Factory() { return new NgxHttpLoaderService(ɵɵinject(NgxHttpLoaderInterceptor)); }, token: NgxHttpLoaderService, providedIn: "root" });
NgxHttpLoaderService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NgxHttpLoaderService.ctorParameters = () => [
    { type: NgxHttpLoaderInterceptor }
];

const NgxLoader = {
    DEFAULT: 'loader-default',
    CLOCK: 'loader-clock',
    DUALRING: 'loader-dual-ring',
    ELLIPSIS: 'loader-ellipsis',
    FACEBOOK: 'loader-facebook',
    GEAR: 'loader-gear',
    GRID: 'loader-grid',
    HEART: 'loader-heart',
    HOURGLASS: 'loader-hourglass',
    JELLYBOX: 'loader-jellybox',
    MULTICIRCLE: 'loader-multicicle',
    RING: 'loader-ring',
    RIPPLE: 'loader-ripple',
    ROLLER: 'loader-roller',
    SPINNER: 'loader-spinner',
    THREEBOUNCE: 'loader-three-bounce',
    WATERWAVE: 'loader-water-wave',
    ROTATINGPLANE: 'loader-rotating-plane',
};

class NgxHttpLoaderComponent {
    constructor(requestService, service, sanitizer) {
        this.requestService = requestService;
        this.service = service;
        this.sanitizer = sanitizer;
        this.customEnumLoader = NgxLoader;
        this.loader = NgxLoader.RIPPLE;
        this.filterUrlRegexPatterns = [];
        this.filterUrls = [];
        this.filterHttpHeaders = [];
        this.filterHttpMethods = [];
        this.delay = 0;
        this.extraDelay = 0;
        this.minDuration = 0;
        this.opacity = 0.8;
        // @Input() public backdropBackgroundColor = 'linear-gradient(45deg, #222428, #444856)';
        // @Input() public backdropBackgroundColor = 'transperent';
        this.backdropBackgroundColor = 'linear-gradient(0deg, black, transparent);';
        this.iconColor = 'white';
        this.title = '';
        this.titleColor = '#fff';
        this.titleSize = '3rem';
        this.subTitle = '';
        this.subTitleColor = '#6c757d';
        this.subTitleSize = '1.2rem';
        this.custom = false;
        this.showuntil = Date.now();
    }
    ngOnChanges(changes) {
        if (this.filterUrlRegexPatterns.length > 0 || this.filterUrls.length > 0
            || this.filterHttpHeaders.length > 0 || this.filterHttpMethods.length > 0)
            this.initAllFilters();
    }
    ngOnInit() {
        this.initAllFilters();
    }
    initAllFilters() {
        this.requestService.setUrlPatterns = this.filterUrlRegexPatterns;
        this.requestService.setFilterUrls = this.filterUrls;
        this.requestService.setFilterMethods = this.filterHttpMethods;
        this.requestService.setFilterHeaders = this.filterHttpHeaders;
        this.initShowObservable();
    }
    initShowObservable() {
        const [show, hide] = partition(($hide) => $hide)(this.requestService.reqStatus);
        this.show$ = merge(this.requestService.reqStatus.pipe(switchMap(() => show.pipe(debounce(() => timer(this.delay))))), show.pipe(switchMap(() => hide.pipe(debounce(() => this.showUpto())))), this.service.isShowLoader).pipe(distinctUntilChanged(), tap(x => this.updateHideDelay(x)));
    }
    updateHideDelay(bool) {
        if (bool)
            this.showuntil = Date.now() + this.minDuration;
    }
    showUpto() {
        return timer(Math.max(this.extraDelay, this.showuntil - Date.now()));
    }
}
NgxHttpLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-http-loader',
                template: "<div *ngIf=\"show$ | async\">\r\n    <ng-template [ngTemplateOutlet]=\"customTemplate || defaultTemplate\"></ng-template>\r\n    <ng-template #defaultTemplate>\r\n        <div class=\"custom-loader vertical-center\"\r\n            [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--background-color: ' + backdropBackgroundColor + '; opacity :' + opacity)\">\r\n            <div class=\"custom-loader-section text-light\"\r\n                [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--iconcolor: ' + iconColor)\">\r\n                <ng-container *ngIf=\"custom\">\r\n                    <ng-template [ngTemplateOutlet]=\"customLoader\"></ng-template>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"!custom\">\r\n                    <lib-gear-loader *ngIf=\"loader === customEnumLoader.GEAR\"></lib-gear-loader>\r\n                    <lib-grid-loader *ngIf=\"loader === customEnumLoader.GRID\"></lib-grid-loader>\r\n                    <lib-dual-ring-loader *ngIf=\"loader === customEnumLoader.DUALRING\"></lib-dual-ring-loader>\r\n                    <lib-clock-loader *ngIf=\"loader === customEnumLoader.CLOCK\"></lib-clock-loader>\r\n                    <lib-default-loader *ngIf=\"loader === customEnumLoader.DEFAULT\"></lib-default-loader>\r\n                    <lib-ellipsis-loader *ngIf=\"loader === customEnumLoader.ELLIPSIS\"></lib-ellipsis-loader>\r\n                    <lib-spinner-loader *ngIf=\"loader === customEnumLoader.SPINNER\"></lib-spinner-loader>\r\n                    <lib-facebook-loader *ngIf=\"loader === customEnumLoader.FACEBOOK\"></lib-facebook-loader>\r\n                    <lib-heart-loader *ngIf=\"loader === customEnumLoader.HEART\"></lib-heart-loader>\r\n                    <lib-hourglass-loader *ngIf=\"loader === customEnumLoader.HOURGLASS\"></lib-hourglass-loader>\r\n                    <lib-ring-loader *ngIf=\"loader === customEnumLoader.RING\"></lib-ring-loader>\r\n                    <lib-ripple-loader *ngIf=\"loader === customEnumLoader.RIPPLE\"></lib-ripple-loader>\r\n                    <lib-roller-loader *ngIf=\"loader === customEnumLoader.ROLLER\"></lib-roller-loader>\r\n                    <lib-water-wave-loader *ngIf=\"loader === customEnumLoader.WATERWAVE\"></lib-water-wave-loader>\r\n                    <lib-multicircle-loader *ngIf=\"loader === customEnumLoader.MULTICIRCLE\"></lib-multicircle-loader>\r\n                    <lib-three-bounce-loader *ngIf=\"loader === customEnumLoader.THREEBOUNCE\"></lib-three-bounce-loader>\r\n                    <lib-jellybox-loader *ngIf=\"loader === customEnumLoader.JELLYBOX\"></lib-jellybox-loader>\r\n                    <lib-rotating-plane *ngIf=\"loader === customEnumLoader.ROTATINGPLANE\"></lib-rotating-plane>\r\n                </ng-container>\r\n                <h1 *ngIf=\"title\" class=\"font-weight-bold text-shadow\"\r\n                    style=\"font-family:Trebuchet MS,Helvetica,sans-serif; width: 50%; margin: 10px auto; margin-top: 20px; word-break: break-all;\"\r\n                    [style.color]=\"titleColor\" [style.fontSize]=\"titleSize\">\r\n                    {{title}}\r\n                </h1>\r\n                <div style=\"width: 50%; margin: 10px auto; word-break: break-all;\" *ngIf=\"subTitle\"\r\n                    [style.color]=\"subTitleColor\" [style.fontSize]=\"subTitleSize\">{{subTitle}}</div>\r\n            </div>\r\n        </div>\r\n    </ng-template>\r\n</div>",
                styles: [".custom-loader{background:var(--background-color);color:#fff;height:100%;left:0;position:fixed;top:0;transition:all .3s linear;width:100%;z-index:99999}.custom-loader .custom-loader-section{color:#f8f9fa;text-align:center;width:100%}.custom-loader ::ng-deep>*{display:inline-block;vertical-align:middle;white-space:normal;z-index:99999999999}.vertical-center:before{content:\"\";display:inline-block;height:100%;vertical-align:middle;width:0}"]
            },] }
];
NgxHttpLoaderComponent.ctorParameters = () => [
    { type: NgxHttpLoaderInterceptor },
    { type: NgxHttpLoaderService },
    { type: DomSanitizer }
];
NgxHttpLoaderComponent.propDecorators = {
    customTemplate: [{ type: Input }],
    customLoader: [{ type: Input }],
    loader: [{ type: Input }],
    filterUrlRegexPatterns: [{ type: Input }],
    filterUrls: [{ type: Input }],
    filterHttpHeaders: [{ type: Input }],
    filterHttpMethods: [{ type: Input }],
    delay: [{ type: Input }],
    extraDelay: [{ type: Input }],
    minDuration: [{ type: Input }],
    opacity: [{ type: Input }],
    backdropBackgroundColor: [{ type: Input }],
    iconColor: [{ type: Input }],
    title: [{ type: Input }],
    titleColor: [{ type: Input }],
    titleSize: [{ type: Input }],
    subTitle: [{ type: Input }],
    subTitleColor: [{ type: Input }],
    subTitleSize: [{ type: Input }],
    custom: [{ type: Input }]
};

class ClockLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
ClockLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-clock-loader',
                template: "<div class=\"clock-loader\"></div>",
                styles: [".clock-loader{--clock-color:var(--primary-color);--clock-hour-length:calc(var(--clock-width)*0.2);--clock-minute-length:calc(var(--clock-width)*0.4);--clock-radius:calc(var(--clock-width)/2);--clock-thickness:0.2rem;--clock-width:4rem;--primary-color:var(--iconcolor);align-items:center;border:3px solid var(--primary-color);border-radius:50%;display:flex;height:var(--clock-width);justify-content:center;margin:20px auto;position:relative;width:var(--clock-width)}.clock-loader:after,.clock-loader:before{animation:spin linear infinite;background:var(--primary-color);border-radius:10px;content:\"\";position:absolute;top:calc(var(--clock-radius)*0.25);transform-origin:center calc(100% - var(--clock-thickness)/2);width:var(--clock-thickness)}.clock-loader:before{animation-duration:2s;height:var(--clock-minute-length)}.clock-loader:after{animation-duration:15s;height:var(--clock-hour-length);top:calc(var(--clock-radius)*0.25 + var(--clock-hour-length))}@keyframes spin{to{transform:rotate(1turn)}}"]
            },] }
];
ClockLoaderComponent.ctorParameters = () => [];

class DefaultLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
DefaultLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-default-loader',
                template: "<div class=\"lds-default\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-default{display:inline-block;height:80px;position:relative;width:80px}.lds-default div{animation:lds-default 1.2s linear infinite;background:var(--iconcolor);border-radius:50%;height:6px;position:absolute;width:6px}.lds-default div:first-child{animation-delay:0s;left:66px;top:37px}.lds-default div:nth-child(2){animation-delay:-.1s;left:62px;top:22px}.lds-default div:nth-child(3){animation-delay:-.2s;left:52px;top:11px}.lds-default div:nth-child(4){animation-delay:-.3s;left:37px;top:7px}.lds-default div:nth-child(5){animation-delay:-.4s;left:22px;top:11px}.lds-default div:nth-child(6){animation-delay:-.5s;left:11px;top:22px}.lds-default div:nth-child(7){animation-delay:-.6s;left:7px;top:37px}.lds-default div:nth-child(8){animation-delay:-.7s;left:11px;top:52px}.lds-default div:nth-child(9){animation-delay:-.8s;left:22px;top:62px}.lds-default div:nth-child(10){animation-delay:-.9s;left:37px;top:66px}.lds-default div:nth-child(11){animation-delay:-1s;left:52px;top:62px}.lds-default div:nth-child(12){animation-delay:-1.1s;left:62px;top:52px}@keyframes lds-default{0%,20%,80%,to{transform:scale(1)}50%{transform:scale(1.5)}}"]
            },] }
];
DefaultLoaderComponent.ctorParameters = () => [];

class DualRingLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
DualRingLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-dual-ring-loader',
                template: "<div class=\"lds-dual-ring\"></div>",
                styles: [".lds-dual-ring{display:inline-block;height:80px;width:80px}.lds-dual-ring:after{animation:lds-dual-ring 1.2s linear infinite;border-bottom:6px solid var(--iconcolor);border-color:currentcolor;border-left:6px solid transparent;border-radius:50%;border-right:6px solid transparent;border-top:6px solid var(--iconcolor);content:\" \";display:block;height:64px;margin:8px;width:64px}@keyframes lds-dual-ring{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}"]
            },] }
];
DualRingLoaderComponent.ctorParameters = () => [];

class EllipsisLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
EllipsisLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ellipsis-loader',
                template: "<div class=\"lds-ellipsis\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-ellipsis{display:inline-block;height:80px;position:relative;width:80px}.lds-ellipsis div{animation-timing-function:cubic-bezier(0,1,1,0);background:var(--iconcolor);border-radius:50%;height:13px;position:absolute;top:33px;width:13px}.lds-ellipsis div:first-child{animation:lds-ellipsis1 .6s infinite;left:8px}.lds-ellipsis div:nth-child(2){animation:lds-ellipsis2 .6s infinite;left:8px}.lds-ellipsis div:nth-child(3){animation:lds-ellipsis2 .6s infinite;left:32px}.lds-ellipsis div:nth-child(4){animation:lds-ellipsis3 .6s infinite;left:56px}@keyframes lds-ellipsis1{0%{transform:scale(0)}to{transform:scale(1)}}@keyframes lds-ellipsis3{0%{transform:scale(1)}to{transform:scale(0)}}@keyframes lds-ellipsis2{0%{transform:translate(0)}to{transform:translate(24px)}}"]
            },] }
];
EllipsisLoaderComponent.ctorParameters = () => [];

class FacebookLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
FacebookLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-facebook-loader',
                template: "<div class=\"lds-facebook\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-facebook{display:inline-block;height:80px;position:relative;width:80px}.lds-facebook div{animation:lds-facebook 1.2s cubic-bezier(0,.5,.5,1) infinite;background:var(--iconcolor);display:inline-block;left:8px;position:absolute;width:16px}.lds-facebook div:first-child{animation-delay:-.24s;left:8px}.lds-facebook div:nth-child(2){animation-delay:-.12s;left:32px}.lds-facebook div:nth-child(3){animation-delay:0;left:56px}@keyframes lds-facebook{0%{height:64px;top:8px}50%,to{height:32px;top:24px}}"]
            },] }
];
FacebookLoaderComponent.ctorParameters = () => [];

class GearLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
GearLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-gear-loader',
                template: "<svg class=\"gear\" style=\"width:64px\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <path id=\"p\"\n        d=\"M94.1 58.8c.6-2.8.9-5.8.9-8.8s-.3-6-.9-8.8l-11.7-.4c-.7-2.6-1.7-5-3-7.3l8-8.5c-3.3-4.9-7.5-9.2-12.5-12.5l-8.5 8c-2.3-1.3-4.7-2.3-7.3-3l-.3-11.6C56 5.3 53 5 50 5s-6 .3-8.8.9l-.4 11.7c-2.6.7-5 1.7-7.3 3l-8.5-8c-4.9 3.3-9.2 7.5-12.5 12.5l8 8.5c-1.3 2.3-2.3 4.7-3 7.3l-11.6.3C5.3 44 5 47 5 50s.3 6 .9 8.8l11.7.4c.7 2.6 1.7 5 3 7.3l-8 8.5c3.3 4.9 7.5 9.2 12.5 12.5l8.5-8c2.3 1.3 4.7 2.3 7.3 3l.4 11.7c2.7.5 5.7.8 8.7.8s6-.3 8.8-.9l.4-11.7c2.6-.7 5-1.7 7.3-3l8.5 8c4.9-3.3 9.2-7.5 12.5-12.5l-8-8.5c1.3-2.3 2.3-4.7 3-7.3l11.6-.3zM50 66.9c-9.3 0-16.9-7.6-16.9-16.9S40.7 33.1 50 33.1 66.9 40.7 66.9 50 59.3 66.9 50 66.9z\">\n    </path>\n</svg>\n<svg class=\"gear\" style=\"width:88px;margin:64px 0 0 -12px;animation-direction:reverse\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <use href=\"#p\"></use>\n</svg>",
                styles: ["@keyframes r{0%{transform:rotate(0deg)}to{transform:rotate(45deg)}}svg.gear{animation:r .5s linear infinite;fill:var(--iconcolor)}"]
            },] }
];
GearLoaderComponent.ctorParameters = () => [];

class GridLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
GridLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-grid-loader',
                template: "<div class=\"lds-grid\">\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n</div>",
                styles: [".lds-grid{display:inline-block;height:80px;position:relative;width:80px}.lds-grid div{animation:lds-grid 1.2s linear infinite;background:var(--iconcolor);border-radius:50%;height:16px;position:absolute;width:16px}.lds-grid div:first-child{animation-delay:0s;left:8px;top:8px}.lds-grid div:nth-child(2){animation-delay:-.4s;left:32px;top:8px}.lds-grid div:nth-child(3){animation-delay:-.8s;left:56px;top:8px}.lds-grid div:nth-child(4){animation-delay:-.4s;left:8px;top:32px}.lds-grid div:nth-child(5){animation-delay:-.8s;left:32px;top:32px}.lds-grid div:nth-child(6){animation-delay:-1.2s;left:56px;top:32px}.lds-grid div:nth-child(7){animation-delay:-.8s;left:8px;top:56px}.lds-grid div:nth-child(8){animation-delay:-1.2s;left:32px;top:56px}.lds-grid div:nth-child(9){animation-delay:-1.6s;left:56px;top:56px}@keyframes lds-grid{0%,to{opacity:1}50%{opacity:.5}}"]
            },] }
];
GridLoaderComponent.ctorParameters = () => [];

class HeartLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
HeartLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-heart-loader',
                template: "<div class=\"lds-heart\">\r\n    <div></div>\r\n</div>",
                styles: [".lds-heart{display:inline-block;height:80px;position:relative;transform:rotate(45deg);transform-origin:40px 40px;width:80px}.lds-heart div{animation:lds-heart 1.2s cubic-bezier(.215,.61,.355,1) infinite;left:32px;top:32px}.lds-heart div,.lds-heart div:after,.lds-heart div:before{background:var(--iconcolor);height:32px;position:absolute;width:32px}.lds-heart div:after,.lds-heart div:before{content:\" \";display:block}.lds-heart div:before{border-radius:50% 0 0 50%;left:-24px}.lds-heart div:after{border-radius:50% 50% 0 0;top:-24px}@keyframes lds-heart{0%{transform:scale(.95)}5%{transform:scale(1.1)}39%{transform:scale(.85)}45%{transform:scale(1)}60%{transform:scale(.95)}to{transform:scale(.9)}}"]
            },] }
];
HeartLoaderComponent.ctorParameters = () => [];

class HourglassLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
HourglassLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-hourglass-loader',
                template: "<div class=\"lds-hourglass\"></div>",
                styles: [".lds-hourglass{display:inline-block;height:80px;position:relative;width:80px}.lds-hourglass:after{animation:lds-hourglass 1.2s infinite;border-bottom:32px solid var(--iconcolor);border-color:var(--iconcolor);border-left:32px solid transparent;border-radius:50%;border-right:32px solid transparent;border-top:32px solid var(--iconcolor);box-sizing:border-box;content:\" \";display:block;height:0;margin:8px;width:0}@keyframes lds-hourglass{0%{animation-timing-function:cubic-bezier(.55,.055,.675,.19);transform:rotate(0)}50%{animation-timing-function:cubic-bezier(.215,.61,.355,1);transform:rotate(900deg)}to{transform:rotate(5turn)}}"]
            },] }
];
HourglassLoaderComponent.ctorParameters = () => [];

class JellyboxLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
JellyboxLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-jellybox-loader',
                template: "<div id=\"loader\">\n    <div id=\"box\"></div>\n    <div id=\"shadow\"></div>\n  </div>",
                styles: ["@keyframes loader{0%{left:-100px}to{left:110%}}#box{animation:animate .5s linear infinite;background:var(--iconcolor);border-radius:3px;height:70px;margin:10px auto;width:70px}@keyframes animate{17%{border-bottom-right-radius:3px}25%{transform:translateY(9px) rotate(22.5deg)}50%{border-bottom-right-radius:40px;transform:translateY(18px) scaleY(.9) rotate(45deg)}75%{transform:translateY(9px) rotate(67.5deg)}to{transform:translateY(0) rotate(90deg)}}#shadow{animation:shadow .5s linear infinite;background:#000;border-radius:50%;height:5px;margin:0 auto;opacity:.1;width:80px}@keyframes shadow{50%{transform:scaleX(1.2)}}"]
            },] }
];
JellyboxLoaderComponent.ctorParameters = () => [];

class MulticircleLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
MulticircleLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-multicircle-loader',
                template: "<div id=\"loader\"></div>",
                styles: ["#loader{animation:spin 2s linear infinite;border:3px solid transparent;border-radius:50%;border-top:3px solid var(--iconcolor);display:block;height:150px;left:50%;margin:-75px 0 0 -75px;position:relative;top:50%;width:150px}#loader:before{animation:spin 3s linear infinite;bottom:5px;left:5px;opacity:.2;right:5px;top:5px}#loader:after,#loader:before{border:3px solid transparent;border-radius:50%;border-top:3px solid var(--iconcolor);content:\"\";position:absolute}#loader:after{animation:spin 1.5s linear infinite;bottom:15px;left:15px;opacity:.6;right:15px;top:15px}@keyframes spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}"]
            },] }
];
MulticircleLoaderComponent.ctorParameters = () => [];

class RingLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RingLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ring-loader',
                template: "<div class=\"lds-ring\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-ring{display:inline-block;height:80px;position:relative;width:80px}.lds-ring div{animation:lds-ring 1.2s cubic-bezier(.5,0,.5,1) infinite;border:8px solid transparent;border-radius:50%;border-top:8px solid var(--iconcolor);box-sizing:border-box;display:block;height:64px;margin:8px;position:absolute;width:64px}.lds-ring div:first-child{animation-delay:-.45s}.lds-ring div:nth-child(2){animation-delay:-.3s}.lds-ring div:nth-child(3){animation-delay:-.15s}@keyframes lds-ring{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}"]
            },] }
];
RingLoaderComponent.ctorParameters = () => [];

class RippleLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RippleLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ripple-loader',
                template: "<div class=\"lds-ripple\"><div></div><div></div></div>",
                styles: [".lds-ripple{display:inline-block;height:80px;position:relative;width:80px}.lds-ripple div{animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite;border:4px solid var(--iconcolor);border-radius:50%;opacity:1;position:absolute}.lds-ripple div:nth-child(2){animation-delay:-.5s}@keyframes lds-ripple{0%{height:0;left:36px;opacity:1;top:36px;width:0}to{height:72px;left:0;opacity:0;top:0;width:72px}}"]
            },] }
];
RippleLoaderComponent.ctorParameters = () => [];

class RollerLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RollerLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-roller-loader',
                template: "<div class=\"lds-roller\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-roller{display:inline-block;height:80px;position:relative;width:80px}.lds-roller div{animation:lds-roller 1.2s cubic-bezier(.5,0,.5,1) infinite;transform-origin:40px 40px}.lds-roller div:after{background:var(--iconcolor);border-radius:50%;content:\" \";display:block;height:7px;margin:-4px 0 0 -4px;position:absolute;width:7px}.lds-roller div:first-child{animation-delay:-36ms}.lds-roller div:first-child:after{left:63px;top:63px}.lds-roller div:nth-child(2){animation-delay:-72ms}.lds-roller div:nth-child(2):after{left:56px;top:68px}.lds-roller div:nth-child(3){animation-delay:-.108s}.lds-roller div:nth-child(3):after{left:48px;top:71px}.lds-roller div:nth-child(4){animation-delay:-.144s}.lds-roller div:nth-child(4):after{left:40px;top:72px}.lds-roller div:nth-child(5){animation-delay:-.18s}.lds-roller div:nth-child(5):after{left:32px;top:71px}.lds-roller div:nth-child(6){animation-delay:-.216s}.lds-roller div:nth-child(6):after{left:24px;top:68px}.lds-roller div:nth-child(7){animation-delay:-.252s}.lds-roller div:nth-child(7):after{left:17px;top:63px}.lds-roller div:nth-child(8){animation-delay:-.288s}.lds-roller div:nth-child(8):after{left:12px;top:56px}@keyframes lds-roller{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}"]
            },] }
];
RollerLoaderComponent.ctorParameters = () => [];

class SpinnerLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
SpinnerLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-spinner-loader',
                template: "<div class=\"lds-spinner\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                styles: [".lds-spinner{color:official;display:inline-block;height:80px;position:relative;width:80px}.lds-spinner div{animation:lds-spinner 1.2s linear infinite;transform-origin:40px 40px}.lds-spinner div:after{background:var(--iconcolor);border-radius:20%;content:\" \";display:block;height:18px;left:37px;position:absolute;top:3px;width:6px}.lds-spinner div:first-child{animation-delay:-1.1s;transform:rotate(0deg)}.lds-spinner div:nth-child(2){animation-delay:-1s;transform:rotate(30deg)}.lds-spinner div:nth-child(3){animation-delay:-.9s;transform:rotate(60deg)}.lds-spinner div:nth-child(4){animation-delay:-.8s;transform:rotate(90deg)}.lds-spinner div:nth-child(5){animation-delay:-.7s;transform:rotate(120deg)}.lds-spinner div:nth-child(6){animation-delay:-.6s;transform:rotate(150deg)}.lds-spinner div:nth-child(7){animation-delay:-.5s;transform:rotate(180deg)}.lds-spinner div:nth-child(8){animation-delay:-.4s;transform:rotate(210deg)}.lds-spinner div:nth-child(9){animation-delay:-.3s;transform:rotate(240deg)}.lds-spinner div:nth-child(10){animation-delay:-.2s;transform:rotate(270deg)}.lds-spinner div:nth-child(11){animation-delay:-.1s;transform:rotate(300deg)}.lds-spinner div:nth-child(12){animation-delay:0s;transform:rotate(330deg)}@keyframes lds-spinner{0%{opacity:1}to{opacity:0}}"]
            },] }
];
SpinnerLoaderComponent.ctorParameters = () => [];

class ThreeBounceLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
ThreeBounceLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-three-bounce-loader',
                template: "<div class=\"wrapper\">\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n</div>",
                styles: [".wrapper{height:60px;left:50%;top:40%;transform:translate(-50%,-50%);width:200px}.circle,.wrapper{position:absolute}.circle{animation:circle .5s ease infinite alternate;background-color:var(--iconcolor);border-radius:50%;height:20px;left:15%;transform-origin:50%;width:20px}@keyframes circle{0%{border-radius:50px 50px 25px 25px;height:5px;top:60px;transform:scaleX(1.7)}40%{border-radius:50%;height:20px;transform:scaleX(1)}to{top:0}}.circle:nth-child(2){animation-delay:.2s;left:45%}.circle:nth-child(3){animation-delay:.3s;left:auto;right:15%}.shadow{animation:shadow .5s ease infinite alternate;background-color:rgba(0,0,0,.5);border-radius:50%;filter:blur(1px);height:4px;left:15%;position:absolute;top:62px;transform-origin:50%;width:20px;z-index:-1}@keyframes shadow{0%{transform:scaleX(1.5)}40%{opacity:.7;transform:scaleX(1)}to{opacity:.4;transform:scaleX(.2)}}.shadow:nth-child(4){animation-delay:.2s;left:45%}.shadow:nth-child(5){animation-delay:.3s;left:auto;right:15%}.wrapper span{color:var(--iconcolor);font-family:Lato;font-size:20px;left:15%;letter-spacing:12px;position:absolute;top:75px}"]
            },] }
];
ThreeBounceLoaderComponent.ctorParameters = () => [];

class WaterWaveLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
WaterWaveLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-water-wave-loader',
                template: "<div class=\"water\"></div>",
                styles: [".water{background-color:var(--iconcolor);border-radius:50%;box-shadow:inset 0 0 30px 0 rgba(0,0,0,.5),0 4px 10px 0 rgba(0,0,0,.5);height:100px;margin:20px auto;overflow:hidden;position:relative;width:100px}.water:after,.water:before{background-color:#fff;content:\"\";height:600px;position:absolute;top:-100px;width:400px}.water:before{background:hsla(0,0%,100%,.7);border-radius:45%}.water:after,.water:before{animation:wave 5s linear infinite}.water:after{background:hsla(0,0%,100%,.3);border-radius:35%}@keyframes wave{0%{transform:rotate(0)}to{transform:rotate(1turn)}}"]
            },] }
];
WaterWaveLoaderComponent.ctorParameters = () => [];

class RotatingPlaneComponent {
    constructor() { }
    ngOnInit() {
    }
}
RotatingPlaneComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-rotating-plane',
                template: "<div class=\"rotating-plane\"></div>",
                styles: [".rotating-plane{animation:rotateplane 1.2s ease-in-out infinite;background-color:var(--iconcolor);height:40px;margin:0 auto;width:40px}@keyframes rotateplane{0%{-webkit-transform:perspective(120px) rotateX(0deg) rotateY(0deg);transform:perspective(120px) rotateX(0deg) rotateY(0deg)}50%{-webkit-transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg);transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg)}to{-webkit-transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg);transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg)}}"]
            },] }
];
RotatingPlaneComponent.ctorParameters = () => [];

class NgxHttpLoaderModule {
    static forRoot() {
        return {
            ngModule: NgxHttpLoaderModule,
            providers: [
                RequestsInterceptorProvider,
            ]
        };
    }
}
NgxHttpLoaderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgxHttpLoaderComponent,
                    GearLoaderComponent,
                    GridLoaderComponent,
                    DualRingLoaderComponent,
                    ClockLoaderComponent,
                    DefaultLoaderComponent,
                    EllipsisLoaderComponent,
                    FacebookLoaderComponent,
                    HeartLoaderComponent,
                    HourglassLoaderComponent,
                    RingLoaderComponent,
                    RippleLoaderComponent,
                    RollerLoaderComponent,
                    SpinnerLoaderComponent,
                    WaterWaveLoaderComponent,
                    ThreeBounceLoaderComponent,
                    MulticircleLoaderComponent,
                    JellyboxLoaderComponent,
                    RotatingPlaneComponent
                ],
                imports: [
                    CommonModule
                ],
                exports: [NgxHttpLoaderComponent]
            },] }
];

/*
 * Public API Surface of ngx-http-loader
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxHttpLoaderComponent, NgxHttpLoaderModule, NgxHttpLoaderService, NgxLoader, NgxHttpLoaderInterceptor as ɵa, RequestsInterceptorProvider as ɵb, GearLoaderComponent as ɵc, GridLoaderComponent as ɵd, DualRingLoaderComponent as ɵe, ClockLoaderComponent as ɵf, DefaultLoaderComponent as ɵg, EllipsisLoaderComponent as ɵh, FacebookLoaderComponent as ɵi, HeartLoaderComponent as ɵj, HourglassLoaderComponent as ɵk, RingLoaderComponent as ɵl, RippleLoaderComponent as ɵm, RollerLoaderComponent as ɵn, SpinnerLoaderComponent as ɵo, WaterWaveLoaderComponent as ɵp, ThreeBounceLoaderComponent as ɵq, MulticircleLoaderComponent as ɵr, JellyboxLoaderComponent as ɵs, RotatingPlaneComponent as ɵt };
//# sourceMappingURL=ngx-http-loader.js.map
